ConvergeLedger.Cluster.MnesiaManager (Converge Ledger v0.1.2)

Manages Mnesia clustering.

When new nodes join the Erlang cluster, this GenServer ensures Mnesia connects to them and replicates the schema and tables.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(opts)