ConvergeLedger.Cluster.MnesiaManager (Converge Ledger v0.1.2)
View SourceManages Mnesia clustering.
When new nodes join the Erlang cluster, this GenServer ensures Mnesia connects to them and replicates the schema and tables.
Summary
Functions
Returns a specification to start this module under a supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.