ConvergeLedger.WatchRegistry (Converge Ledger v0.1.2)
View SourceRegistry for Watch stream subscribers.
Manages subscriptions to context updates. When entries are appended, this registry notifies all subscribers watching that context.
Summary
Functions
Returns a specification to start this module under a supervisor.
Notifies all subscribers of a new entry.
Starts the watch registry.
Subscribes the calling process to updates for a context.
Returns the number of subscribers for a context.
Unsubscribes the calling process from a context.
Types
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Notifies all subscribers of a new entry.
Called by the Store after appending an entry.
Starts the watch registry.
Subscribes the calling process to updates for a context.
Returns {:ok, ref} where ref is a monitor reference that will be
used to clean up if the subscriber crashes.
Returns the number of subscribers for a context.
Unsubscribes the calling process from a context.